#!/usr/bin/env python

import os
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()

# load setup.cfg. Preferring static setup.cfg to dynamic setup.py for deterministic lib creation
setup()
